@@ -13,7 +13,7 @@ class MainHandler(tornado.web.RequestHandler):
         cls.config = config
 
     def get(self):
-        if self.request.get_arguments('wsdl'):
+        if 'wsdl' in self.request.arguments:
             self.set_header( 'Content-Type', 'text/xml' )
             with open('./wsdl.xml') as f:
                 return self.write(f.read())
